@@ -216,13 +216,24 @@ namespace Tasque.Backends.RtmBackend
 					Logger.Debug("RTM Auth Token is valid!");
 					Logger.Debug("Setting configured status to true");
 					configured = true;
-				} catch (Exception e) {
+				} catch (RtmNet.RtmApiException e) {
+					
 					Application.Preferences.Set (Preferences.AuthTokenKey, null);
 					Application.Preferences.Set (Preferences.UserIdKey, null);
 					Application.Preferences.Set (Preferences.UserNameKey, null);
 					rtm = null;
 					rtmAuth = null;
 					Logger.Error("Exception authenticating, reverting" + e.Message);
+				} 			
+				catch (RtmNet.RtmWebException e) {
+					rtm = null;
+					rtmAuth = null;
+					Logger.Error("Not connected to RTM, maybe proxy: #{0}", e.Message);
+ 				}
+				catch (System.Net.WebException e) {
+					rtm = null;
+					rtmAuth = null;
+					Logger.Error("Problem connecting to internet: #{0}", e.Message);
 				}
 			}
 
@@ -530,12 +541,11 @@ namespace Tasque.Backends.RtmBackend
 		/// Update the model to match what is in RTM
 		/// FIXME: This is a lame implementation and needs to be optimized
 		/// </summary>		
-		private void UpdateCategories()
+		private void UpdateCategories(Lists lists)
 		{
 			Logger.Debug("RtmBackend.UpdateCategories was called");
 			
 			try {
-				Lists lists = rtm.ListsGetList();
 				foreach(List list in lists.listCollection)
 				{
 					RtmCategory rtmCategory = new RtmCategory(list);
@@ -568,12 +578,11 @@ namespace Tasque.Backends.RtmBackend
 		/// Update the model to match what is in RTM
 		/// FIXME: This is a lame implementation and needs to be optimized
 		/// </summary>		
-		private void UpdateTasks()
+		private void UpdateTasks(Lists lists)
 		{
 			Logger.Debug("RtmBackend.UpdateTasks was called");
 			
 			try {
-				Lists lists = rtm.ListsGetList();
 				foreach(List list in lists.listCollection)
 				{
 					Tasks tasks = null;
@@ -586,6 +595,8 @@ namespace Tasque.Backends.RtmBackend
 					if(tasks != null) {
 						foreach(List tList in tasks.ListCollection)
 						{
+							if (tList.TaskSeriesCollection == null)
+								continue;
 							foreach(TaskSeries ts in tList.TaskSeriesCollection)
 							{
 								RtmTask rtmTask = new RtmTask(ts, this, list.ID);
@@ -636,8 +647,9 @@ namespace Tasque.Backends.RtmBackend
 				runRefreshEvent.Reset();
 
 				if(rtmAuth != null) {
-					UpdateCategories();			
-					UpdateTasks();
+					Lists lists = rtm.ListsGetList();
+					UpdateCategories(lists);
+					UpdateTasks(lists);
 				}
 				if(!initialized) {
 					initialized = true;
