@@ -153,6 +153,7 @@ namespace Tasque
 			addTaskEntry.Activated += OnAddTaskEntryActivated;
 			addTaskEntry.FocusInEvent += OnAddTaskEntryFocused;
 			addTaskEntry.FocusOutEvent += OnAddTaskEntryUnfocused;
+			addTaskEntry.DragDataReceived += OnAddTaskEntryDragDataReceived;
 			addTaskEntry.Show ();
 			topHBox.PackStart (addTaskEntry, true, true, 0);
 			
@@ -186,6 +187,8 @@ namespace Tasque
 						(uint) Gdk.Key.q,
 						Gdk.ModifierType.ControlMask,
 						Gtk.AccelFlags.Visible);
+
+			this.KeyPressEvent += KeyPressed;
 			
 			topHBox.Show ();
 			mainVBox.PackStart (topHBox, false, false, 0);
@@ -236,7 +239,6 @@ namespace Tasque
 			Application.Preferences.SettingChanged += OnSettingChanged;
 		}
 
-
 		void PopulateWindow()
 		{
 			// Add in the groups
@@ -468,7 +470,9 @@ namespace Tasque
 
 		public static bool ShowOriginalStatus ()
 		{
-			status = string.Format ("Tasks loaded: {0}", TaskWindow.lastLoadedTime);
+			// Translators: This status shows the date and time when the task list was last refreshed
+			status = string.Format (Catalog.GetString ("Tasks loaded: {0}"),
+			                        TaskWindow.lastLoadedTime);
 			TaskWindow.ShowStatus (status);
 			return false;
 		}
@@ -923,6 +927,13 @@ namespace Tasque
 			OnAddTask (sender, args);
 		}
 
+		void OnAddTaskEntryDragDataReceived(object sender, DragDataReceivedArgs args)
+		{
+			// Change the text directly to the dropped text
+			addTaskEntry.Text = args.SelectionData.Text;
+			addTaskEntry.ModifyText (Gtk.StateType.Normal);
+		}
+
 		void OnAddTask (object sender, EventArgs args)
 		{
 			string enteredTaskText = addTaskEntry.Text.Trim ();
@@ -1092,6 +1103,39 @@ namespace Tasque
 					item.Activated += OnEditTask;
 					popupMenu.Add (item);
 
+					/*
+					 * Depending on the currently selected task's category, we create a context popup
+					 * here in order to enable changing categories. The list of available categories
+					 * is pre-filtered as to not contain the current category and the AllCategory.
+					 */
+					TreeModelFilter filteredCategories = new TreeModelFilter(Application.Backend.Categories, null);
+					filteredCategories.VisibleFunc = delegate(TreeModel t, TreeIter i) {
+						ICategory category = t.GetValue (i, 0) as ICategory;
+						if (category == null || category is AllCategory || category.Equals(clickedTask.Category))
+							return false;
+						return true;
+					};
+
+					// The categories submenu is only created in case we actually provide at least one category.
+					if (filteredCategories.GetIterFirst(out iter))
+					{
+						Menu categoryMenu = new Menu();
+						CategoryMenuItem categoryItem;
+
+						filteredCategories.Foreach(delegate(TreeModel t, TreePath p, TreeIter i) {
+							categoryItem = new CategoryMenuItem((ICategory)t.GetValue(i, 0));
+							categoryItem.Activated += OnChangeCategory;
+							categoryMenu.Add(categoryItem);
+							return false;
+						});
+					
+						// TODO Needs translation.
+						item = new ImageMenuItem(Catalog.GetString("_Change category"));
+						item.Image = new Gtk.Image(Gtk.Stock.Convert, IconSize.Menu);
+						item.Submenu = categoryMenu;
+						popupMenu.Add(item);
+					}
+				
 					popupMenu.ShowAll();
 					popupMenu.Popup ();
 				
@@ -1165,7 +1209,8 @@ namespace Tasque
 			Logger.Debug("Backend sync finished");
 			if (Application.Backend.Configured) {
 				string now = DateTime.Now.ToString ();
-				status = string.Format ("Tasks loaded: {0}", now);
+				// Translators: This status shows the date and time when the task list was last refreshed
+				status = string.Format (Catalog.GetString ("Tasks loaded: {0}"), now);
 				TaskWindow.lastLoadedTime = now;
 				TaskWindow.ShowStatus (status);
 				RebuildAddTaskMenu (Application.Backend.Categories);
@@ -1177,10 +1222,30 @@ namespace Tasque
 				addTaskEntry.ModifyText (Gtk.StateType.Normal, insensitiveColor);
 			} else {
 				string status =
-					string.Format ("Not connected.");
+					string.Format (Catalog.GetString ("Not connected."));
 				TaskWindow.ShowStatus (status);
 			}
 		}
+
+		void KeyPressed (object sender, Gtk.KeyPressEventArgs args)
+		{
+			args.RetVal = true;
+			if (args.Event.Key == Gdk.Key.Escape) {
+				if ((GdkWindow.State & Gdk.WindowState.Maximized) > 0)
+					Unmaximize ();
+				Hide ();
+				return;
+			}
+			args.RetVal = false;
+		}
+
+		private void OnChangeCategory(object sender, EventArgs args)
+		{
+			if (clickedTask == null)
+				return;
+
+			clickedTask.Category = ((CategoryMenuItem)sender).Category;
+		}
 		#endregion // Event Handlers
 		
 		#region Private Classes
